@@ -11,6 +11,8 @@ ConfigFile="SleepAnalyser.conf"
 developmentconfigFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/" #development PC
 developmentRecordFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/data/" #development PC
 
+SongFolder="/home/user/MyDocs/.sounds"
+
 dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the record files
 
 LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!
@@ -111,7 +113,8 @@ SwitchedModes=False
 OfflineMode=False
 PreviousMode="normal"
 SilentProfile=False
-PreviouseProfile="silent"
+PreviousProfile="silent"
+PreviousVolume=50
 
 language="" #2-letter country code
 
@@ -124,9 +127,9 @@ interval=0
 #GraphStartMinutes=0
 #AlarmTimeSec=0 #absolute alarm time in seconds
 #AlarmDate=0
-AlarmHour=-1
-AlarmMinute=-1
-#AlarmIsSet=False
+AlarmHour=7
+AlarmMinute=0
+UseAlarm=False
 AlarmIsActive=False
 AlarmTimeWindow=30 #in minutes
 AlarmID=-1 #cookie for communication to system
@@ -167,8 +170,8 @@ Light_Sleep_ColorDark= "#001400"
 Awake_Color=                "#860000" #red
 Awake_ColorDark=         "#4C0000"
 
-
-
+Lucid_Dream_Color=      "#00C800" #"#B3FF8F"
+WakeUp_Color=             "red" #"#FEA2FF"
 
 
 noiseReduction=4  #Smoothing of derivation data
@@ -178,3 +181,17 @@ limitMovement=250
 
 
 Animation=0
+
+
+Use_Lucid_Dream_Song=False
+Lucid_Dream_Song=""
+Lucid_Dream_Song_Volume=30
+Lucid_Dream_Song_Delay=600
+Lucid_Dream_Song_Duration = 0
+Lucid_Dream_SongIsActive=False
+
+Use_WakeUp_Song=False
+WakeUp_Song=""
+WakeUp_Song_Volume=50
+WakeUp_Song_Duration=0
+WakeUp_SongIsActive=False
