@@ -75,6 +75,7 @@ def CreateHeader():
 
     h=h+"\n"+"Start time: "+strftime(data.dateformat,  records.StartTime_tuple)
 
+
     if(records.AlarmIsSet==True):
         if(records.AlarmTime_tuple!=-1):
             h=h+"\n"+"Alarm: "+strftime(data.dateformat,records.AlarmTime_tuple)
@@ -89,7 +90,47 @@ def CreateHeader():
 
     h=h+"\n"+"Note: "+str(records.Note.encode( "utf-8" ))
 
-    h=h+"\n"+"Time,   AccX, AccY, AccY:\n"
+
+    if(records.Use_Lucid_Dream_Song==True):
+        if(records.Lucid_Dream_Song_Start_tuple != -1):
+            h=h+"\n"+ "Lucid dream song start: "+strftime(data.dateformat, records.Lucid_Dream_Song_Start_tuple)
+        else:
+            h=h+"\n"+ "Lucid dream song start: never"
+        h=h+"\n"+ "Lucid dream song: "+str(records.Lucid_Dream_Song)
+        h=h+"\n"+ "Lucid dream song delay: "+str(records.Lucid_Dream_Song_Delay)
+        h=h+"\n"+ "Lucid dream song duration: "+str(records.Lucid_Dream_Song_Duration)
+        h=h+"\n"+ "Lucid dream song volume: "+str(records.Lucid_Dream_Song_Volume)
+    else:
+        h=h+"\n"+ "Lucid dream song start: Not set"
+        h=h+"\n"+ "Lucid dream song: Not set"
+        h=h+"\n"+ "Lucid dream song delay: Not set"
+        h=h+"\n"+ "Lucid dream song volume: Not set"
+
+
+    if(records.Use_WakeUp_Song==True):
+        if(records.WakeUp_Song_Start_tuple != -1):
+            h=h+"\n"+ "WakeUp song start: "+strftime(data.dateformat, records.WakeUp_Song_Start_tuple)
+        else:
+            h=h+"\n"+ "WakeUp song start: never"
+        h=h+"\n"+ "WakeUp song: "+str(records.WakeUp_Song)
+        h=h+"\n"+ "WakeUp song duration: "+str(records.WakeUp_Song_Duration)
+        h=h+"\n"+ "WakeUp song volume: "+str(records.WakeUp_Song_Volume)
+    else:
+        h=h+"\n"+ "WakeUp song start: Not set"
+        h=h+"\n"+ "WakeUp song: Not set"
+        h=h+"\n"+ "WakeUp song duration: Not set"
+        h=h+"\n"+ "WakeUp song volume: Not set"
+
+
+    #for future usage
+    h=h+"\n"+"Spare"
+    h=h+"\n"+"Spare"
+    h=h+"\n"+"Spare"
+    h=h+"\n"+"Spare"
+    h=h+"\n"+"Spare"
+
+
+    h=h+"\n"+"Time, AccX, AccY, AccY:\n"
 
 #    print "Record header:\n"+h+"\n"
     if(data.debug==True): print "##############################\nHeader:\n"+h+"\n##############################"
@@ -151,6 +192,9 @@ def LoadFileList():
 
 
 
+
+
+
 ###########################################################################
 ##  Load record file  to read and visualise it
 ###########################################################################
@@ -170,9 +214,9 @@ def LoadRecord():
     try: #read header data
        #process header line 1
         tmp=file.readline()
-    #        print tmp
         header=string.split(tmp, ", ")
         records.SWversion=float(string.replace(header[4], "SW version:",  ""))
+        print "File has software version", records.SWversion
         if(records.SWversion<1.6): #workaround for old files
             print "Record is older than SW version 1.6, use old protocol"
     #            print "Sorry, records older than SW version 1.6 are not compatible."
@@ -203,17 +247,14 @@ def LoadRecord():
         else:
            #process header line 2
             tmp=file.readline()
-    #        print tmp
             tmp=string.replace(tmp[:-1], "Start time: ",  "")
             records.StartTime_tuple=time.strptime(tmp,  data.dateformat)
             records.StartTime_seconds=Tuple2Seconds( records.StartTime_tuple)
 
            #process header line 3
             tmp=file.readline()
-    #        print tmp
             if(tmp[:-1]!="No alarm set"):
                 if(data.debug==True): print "An alarm is set"
-#                records.AlarmIsSet=True
                 tmp=string.replace(tmp[:-1], "Alarm: ",  "")
                 records.AlarmTime_tuple=time.strptime(tmp,  data.dateformat)
                 records.AlarmTime_seconds=Tuple2Seconds( records.AlarmTime_tuple)
@@ -222,8 +263,6 @@ def LoadRecord():
 
            #process header line 4
             tmp=file.readline()
-    #        print tmp
-#            if(records.AlarmIsSet==True):
             tmp=string.replace(tmp[:-1], "Alarm Time Window Start: ",  "")
             if(tmp!="Not set"):
                 records.AlarmTimeWindowStart_tuple=time.strptime(tmp,  data.dateformat)
@@ -231,8 +270,6 @@ def LoadRecord():
 
            #process header line 5
             tmp=file.readline()
-    #        print tmp
-#            if(records.AlarmIsSet==True):
             tmp=string.replace(tmp[:-1], "Alarm Time Window End: ",  "")
             if(tmp!="Not set"):
                 records.AlarmTimeWindowEnd_tuple=time.strptime(tmp,  data.dateformat)
@@ -244,7 +281,68 @@ def LoadRecord():
             tmp=file.readline()
             records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ",  "")
 
-          #process header line 7
+
+
+            if(records.SWversion>=2.0):
+                #process header line 7..10
+                tmp=file.readline()
+                tmp=string.replace(tmp[:-1], "Lucid dream song start: ",  "")
+                if(tmp=="Not set"):
+                    print "=> Not set"
+                    records.Use_Lucid_Dream_Song=False
+                    file.readline() #drop line
+                    file.readline() #drop line
+                    file.readline() #drop line
+                    file.readline() #drop line
+                else: #used lucid dream option
+                    records.Use_Lucid_Dream_Song=True
+                    if(tmp!="never"):
+                        records.Lucid_Dream_Song_Start_tuple=time.strptime(tmp,  data.dateformat)
+                    else:
+                        records.Lucid_Dream_Song_Start_tuple=-1
+                    tmp=file.readline()
+                    records.Lucid_Dream_Song=string.replace(tmp[:-1], "Lucid dream song: ",  "")
+                    tmp=file.readline()
+                    records.Lucid_Dream_Song_Delay=int(string.replace(tmp[:-1], "Lucid dream song delay: ",  ""))
+                    tmp=file.readline()
+                    records.Lucid_Dream_Song_Duration=int(string.replace(tmp[:-1], "Lucid dream song duration: ",  ""))
+                    tmp=file.readline()
+                    records.Lucid_Dream_Song_Volume=int(string.replace(tmp[:-1], "Lucid dream song volume: ",  ""))
+
+
+                #process header line 11..14
+                tmp=file.readline()
+                tmp=string.replace(tmp[:-1], "WakeUp song start: ",  "")
+                if(tmp=="Not set"):
+                    records.Use_WakeUp_Song=False
+                    file.readline() #drop line
+                    file.readline() #drop line
+                    file.readline() #drop line
+                else: #used lucid dream option
+                    records.Use_WakeUp_Song=True
+                    if(tmp!="never"):
+                        records.WakeUp_Song_Start_tuple=time.strptime(tmp,  data.dateformat)
+                    else:
+                        records.WakeUp_Song_Start_tuple=-1
+                    tmp=file.readline()
+                    records.WakeUp_Song=string.replace(tmp[:-1], "WakeUp song: ",  "")
+                    tmp=file.readline()
+                    records.WakeUp_Song_Duration=int(string.replace(tmp[:-1], "WakeUp song duration: ",  ""))
+                    tmp=file.readline()
+                    records.WakeUp_Song_Volume=int(string.replace(tmp[:-1], "WakeUp song volume: ",  ""))
+
+
+
+            if(records.SWversion>=2.0):
+                #spare lines 15..19
+                tmp=file.readline() #drop line
+                tmp=file.readline() #drop line
+                tmp=file.readline() #drop line
+                tmp=file.readline() #drop line
+                tmp=file.readline() #drop line
+
+
+          #process header line 20
             tmp=file.readline()  #not used, column header
 
 
@@ -258,6 +356,8 @@ def LoadRecord():
         return 8
 
 
+    PrintRecordData()
+
 
     records.Index=0
     try: #get data
@@ -333,6 +433,12 @@ def LoadRecord():
 
 
 
+#def GetLine(replace=""):
+#    tmp=file.readline()
+#    tmp=string.replace(tmp[:-1], replace,  "")
+#    return tmp
+
+
 
 ###########################################################################
 ##
