@@ -148,6 +148,13 @@ def LoadConfig():
     except:
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))
 
+    try:
+        tmp = config.get('main', 'UseAlarm')
+        if(tmp=="True"): data.UseAlarm=True
+        else: data.UseAlarm=False
+    except:
+        config.set('main', 'UseAlarm', str(data.UseAlarm))
+
     try:
         data.AlarmHour = config.getint('main', 'AlarmHour')
     except:
@@ -170,6 +177,65 @@ def LoadConfig():
     except:
         config.set('main', 'StopAfterAlarm', str(data.StopAfterAlarm))
 
+
+
+    try:
+        tmp = config.get('main', 'Use_Lucid_Dream_Song')
+        if(tmp=="True"): data.Use_Lucid_Dream_Song=True
+        else: data.Use_Lucid_Dream_Song=False
+    except:
+        config.set('main', 'Use_WakeUp_Song', str(data.Use_WakeUp_Song))
+
+    try:
+        data.Lucid_Dream_Song = config.get('main', 'Lucid_Dream_Song')
+    except:
+        config.set('main', 'Lucid_Dream_Song', str(data.Lucid_Dream_Song))
+
+    try:
+        data.Lucid_Dream_Song_Volume = config.getint('main', 'Lucid_Dream_Song_Volume')
+    except:
+        config.set('main', 'Lucid_Dream_Song_Volume', str(data.Lucid_Dream_Song_Volume))
+
+    try:
+        data.Lucid_Dream_Song_Delay = config.getint('main', 'Lucid_Dream_Song_Delay')
+    except:
+        config.set('main', 'Lucid_Dream_Song_Delay', str(data.Lucid_Dream_Song_Delay))
+
+    try:
+        data.Lucid_Dream_Song_Duration = config.getint('main', 'Lucid_Dream_Song_Duration')
+    except:
+        config.set('main', 'Lucid_Dream_Song_Duration', str(data.Lucid_Dream_Song_Duration))
+
+
+
+    try:
+        tmp = config.get('main', 'Use_WakeUp_Song')
+        if(tmp=="True"): data.Use_WakeUp_Song=True
+        else: data.Use_WakeUp_Song=False
+    except:
+        config.set('main', 'Use_WakeUp_Song', str(data.Use_WakeUp_Song))
+
+    try:
+        data.WakeUp_Song = config.get('main', 'WakeUp_Song')
+    except:
+        config.set('main', 'WakeUp_Song', str(data.WakeUp_Song))
+
+    try:
+        data.WakeUp_Song_Volume = config.getint('main', 'WakeUp_Song_Volume')
+    except:
+        config.set('main', 'WakeUp_Song_Volume', str(data.WakeUp_Song_Volume))
+
+    try:
+        data.WakeUp_Song_Duration = config.getint('main', 'WakeUp_Song_Duration')
+    except:
+        config.set('main', 'WakeUp_Song_Duration', str(data.WakeUp_Song_Duration))
+
+
+
+
+
+
+
     print "Configuration successful loaded from "+data.ConfigFile
 
     return config
@@ -260,72 +326,116 @@ def Index2Tuple(Index):
 def SwitchModes(start):
     if(data.demo==False): #We are on a N900
         if(data.QuickMode==False):  #only do in normal recording mode
-
             if(start==True): #start of recording
                 if(data.SwitchedModes==False): #protection so it only gets switched once
                     data.SwitchedModes=True
                     if(data.OfflineMode==True): #change to offline mode
-                        try:
-                            cmd="dbus-send --system --dest=com.nokia.mce --print-reply --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode"
-                            ret=os.popen2(cmd) #get current mode
-                            p=ret[1].readline() #not used
-                            p=ret[1].readline()
-                            tmp=string.split(p,  "\"")
-                            data.PreviousMode=tmp[1]
-                            if(data.PreviousMode=="normal"): #was normal, change to offline
-                                print "Change to offline mode"
-                                cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
-                                os.popen(cmd)
-                        except:
-                            pass
-
+                        set_profile(False)
                     if(data.SilentProfile==True): #change to silent profile
-                        try:
-                            cmd="dbus-send --type=method_call --print-reply --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.get_profile"
-                            ret=os.popen2(cmd) #get current profile
-                            p=ret[1].readline() #not used
-                            p=ret[1].readline()
-                            tmp=string.split(p,  "\"")
-                            data.PreviousProfile=tmp[1]
-                            if(data.PreviousProfile=="general"): #was general profile, change to silent profile
-                                cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
-                                os.popen(cmd)
-                                print "Silent Profile activated"
-                                txt=_("Silent Profile activated")
-                                cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
-                                os.popen(cmd)
-                        except:
-                            pass
-
-
+                        set_silent(True)
 
             else: #end of recording
                 if(data.SwitchedModes==True): #protection so it only gets switched once
                     data.SwitchedModes=False
                     if(data.OfflineMode==True and data.demo!=1): #change to online mode
-                        try:
-                            if(data.PreviousMode=="normal"): #was online mode (before start measurement), so restore
-                                print "Change to online mode"
-                                cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
-                                os.popen(cmd)
-                        except:
-                            pass
+                       set_profile(True)
                     if(data.SilentProfile==True and data.demo!=1): #change to general profile
-                        try:
-                            if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
-                                cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
-                                os.popen(cmd)  #set profile
-                                print "General Profile activated"
-                                txt=_("General Profile activated")
-                                cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
-                                os.popen(cmd)  #notification
-                        except:
-                            pass
+                        set_silent(False)
 
 
 
 
 
+def set_profile(online):
+    if(online==True):
+        try:
+            if(data.PreviousMode=="normal"): #was online mode (before start measurement), so restore
+                print "Change to online mode"
+                cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
+                os.popen(cmd)
+        except:
+            pass
+    else: #offline
+        try:
+            cmd="dbus-send --system --dest=com.nokia.mce --print-reply --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode"
+            ret=os.popen2(cmd) #get current mode
+            p=ret[1].readline() #not used
+            p=ret[1].readline()
+            tmp=string.split(p,  "\"")
+            data.PreviousMode=tmp[1]
+            if(data.PreviousMode=="normal"): #was normal, change to offline
+                print "Change to offline mode"
+                cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
+                os.popen(cmd)
+        except:
+            pass
+
+
+
+
+
+
+def set_silent(silent):
+    if(silent==True):
+        try:
+            cmd="dbus-send --type=method_call --print-reply --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.get_profile"
+            ret=os.popen2(cmd) #get current profile
+            p=ret[1].readline() #not used
+            p=ret[1].readline()
+            tmp=string.split(p,  "\"")
+            data.PreviousProfile=tmp[1]
+            if(data.PreviousProfile=="general"): #was general profile, change to silent profile
+                cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
+                os.popen(cmd)
+                print "Silent Profile activated"
+                txt=_("Silent Profile activated")
+                cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
+                os.popen(cmd)
+        except:
+            pass
+    else: #normal
+        try:
+            if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
+                cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
+                os.popen(cmd)  #set profile
+                print "General Profile activated"
+                txt=_("General Profile activated")
+                cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
+                os.popen(cmd)  #notification
+        except:
+            pass
+
+
+
+
+
+
+
+def set_volume(percent):
+    cmd="dbus-send --type=method_call --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.extension.set_extension_property string:volume variant:uint32:"+str(percent)
+    os.popen(cmd)
+
+
+
+
+def PlaySong(volume, filename):
+    print strftime("%x %X"), "Play", filename, "with volume", volume
+    cmd="dbus-send --print-reply --dest=com.nokia.mediaplayer /com/nokia/mediaplayer com.nokia.mediaplayer.mime_open string:\"file:///"+str(filename)+"\""
+    notify_txt=_("Open Song in media player, set volume to ")+ str(volume) + "%"
+    notify_cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+notify_txt+"\""
+    os.popen(notify_cmd)
+    set_volume(volume)
+    b = os.popen(cmd)
+    b.close()
+
+
+def GetSongLength(filename):
+    print "get song length for file:", filename
+    output = os.popen("ffmpeg -i \""+str(filename)+"\" 2>&1 | grep Duration").read() # run ffmpeg and make the output look like a file I can read
+    arr=output.split(".")
+    arr=arr[0].split(":")
+    duration=int(int(arr[1])*3600+int(arr[2])*60+int(arr[3]))
+    return duration
 
 
 
