@@ -341,13 +341,15 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
         #DRAW movement bars (yellow)
         paint.setPen(QtGui.QColor(data.MovementBarColor))
-        peak=0
+#        peak=0
         for p in range(0,  records.Index-data.Derivation,  Xscale):
             i=p-GraphStart_index
             peak=0
             for j in range(0, Xscale):
                 if(records.arrData[5][p+j]>peak): peak=records.arrData[5][p+j]
             x=i/Xscale
+            if(peak==""): peak=0 #temporary bugfix
+#            print peak, data.Yscale_Movement, data.Ysize
             h=min(peak*data.Yscale_Movement/2,  data.Ysize-17) #cut off if higher than graph border
             paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
 
@@ -390,6 +392,46 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
 
+       #Lucid dream option
+        if(records.Use_Lucid_Dream_Song==True and records.Lucid_Dream_Song_Start_tuple!=-1):
+            PrintRecordData(False)
+            paint.setBrush(QtGui.QColor(data.Lucid_Dream_Color))
+            paint.setPen(QtGui.QColor(data.Lucid_Dream_Color))
+            x0=Tuple2Index(records.Lucid_Dream_Song_Start_tuple)-data.Derivation*Xscale
+            x00=(x0-GraphStart_index)/Xscale
+            t=Seconds2Tuple(Tuple2Seconds(records.Lucid_Dream_Song_Start_tuple)+(records.Lucid_Dream_Song_Duration))
+            x1=Tuple2Index(t)-data.Derivation*Xscale
+            x01=(x1-GraphStart_index)/Xscale
+            y=20
+            paint.drawPolygon(QPointF(x00, y-4), QPointF(x00, y+4), QPointF(x00+4, y))
+            paint.drawLine(x00, y, x01, y)
+
+
+
+
+
+
+
+       #WakeUp option
+        if(records.Use_WakeUp_Song==True and records.WakeUp_Song_Start_tuple!=-1):
+            PrintRecordData(False)
+            paint.setBrush(QtGui.QColor(data.WakeUp_Color))
+            paint.setPen(QtGui.QColor(data.WakeUp_Color))
+            x0=Tuple2Index(records.WakeUp_Song_Start_tuple)-data.Derivation*Xscale
+            x00=(x0-GraphStart_index)/Xscale
+            t=Seconds2Tuple(Tuple2Seconds(records.WakeUp_Song_Start_tuple)+(records.WakeUp_Song_Duration))
+            x1=Tuple2Index(t)-data.Derivation*Xscale
+            x01=(x1-GraphStart_index)/Xscale
+            y=20
+            paint.drawPolygon(QPointF(x00, y-4), QPointF(x00, y+4), QPointF(x00+4, y))
+            paint.drawLine(x00, y, x01, y)
+
+
+
+
+
+
+
 
 
        #ALARM VISUALISATION
@@ -432,19 +474,12 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                             a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation
                         a00=(a0-GraphStart_index)/Xscale
 
-
-
-
 #                        gradient = QtGui.QRadialGradient(200,  100,  5)
                         gradient = QtGui.QRadialGradient(a00,  20,  3)
                         gradient.setColorAt(0, QtGui.QColor(255, 152, 152))
                         gradient.setColorAt(1, QtGui.QColor(255, 0, 0))
                         paint.setBrush(QtGui.QBrush(gradient))
 
-
-
-
-
 #                        paint.drawEllipse(100, 0, 200, 200)
                         paint.drawEllipse(a00-5, 15, 10, 10)
 
@@ -455,26 +490,37 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
 
+
+
+
+
+
+
+
+
+
+
         #DRAW Trigger line
-        if(records.statusID=="OK"):
-            if(data.run==False):  #only show trigger level stored in record when recording is finished
-                t=records.Trigger
-            else:
-                t=data.Trigger
-            y=(data.Ysize-(t*data.Yscale_Sleep_Pattern*3/40))+10
-            paint.setPen(QtGui.QColor(255,  255,  255, 200))
-            paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
-            if(y<18):
-                y=33
-                #draw arrow
-                xa=data.GraphBitMapLen-37
-                ya=y-21
-                paint.drawLine(xa, ya,    xa, ya-9) #arrow
-                paint.drawLine(xa, ya-9,    xa-3, ya-6) #arrow
-                paint.drawLine(xa, ya-9,    xa+3, ya-6) #arrow
-            elif(y<33):
-                y=y+17
-            paint.drawText(data.GraphBitMapLen-31, y-19, str(t)) #Trigger level
+        if(records.AlarmIsSet==True or data.QuickMode==True): #alarm time window is set, show it
+            if(records.statusID=="OK"):
+                if(data.run==False):  #only show trigger level stored in record when recording is finished
+                    t=records.Trigger
+                else:
+                    t=data.Trigger
+                y=(data.Ysize-(t*data.Yscale_Sleep_Pattern*3/40))+10
+                paint.setPen(QtGui.QColor(255,  255,  255, 200))
+                paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
+                if(y<18):
+                    y=33
+                    #draw arrow
+                    xa=data.GraphBitMapLen-37
+                    ya=y-21
+                    paint.drawLine(xa, ya,    xa, ya-9) #arrow
+                    paint.drawLine(xa, ya-9,    xa-3, ya-6) #arrow
+                    paint.drawLine(xa, ya-9,    xa+3, ya-6) #arrow
+                elif(y<33):
+                    y=y+17
+                paint.drawText(data.GraphBitMapLen-31, y-19, str(t)) #Trigger level
 
 
         #show parameters
@@ -530,7 +576,8 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 #TODO: improve function!!!!
 def MakeNoise_if_over_trigger(peak):
     #beep in test mode
-    if(peak>data.Trigger): #if last value is over peak
+#    if(peak>data.Trigger): #if last value is over peak
+    if(peak>(data.Trigger*data.Yscale_Sleep_Pattern*3/40)): #Trigger Alarm
 #        if(data.QuickMode==True and (records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
         if((records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
             if(data.debug==True): print "Beep"
@@ -659,7 +706,7 @@ def GenerateStatisticData():
 
     #time percent
     t_total=(records.EndTime_seconds-records.StartTime_seconds)
-    if(t_total==0):  t_total=1 #division by zerro prevention
+    if(t_total==0):  t_total=1 #division by zero prevention
     records.arrStatData[0][3]=records.arrStatData[0][0]*100/t_total
     records.arrStatData[1][3]=records.arrStatData[1][0]*100/t_total
     records.arrStatData[2][3]=records.arrStatData[2][0]*100/t_total
@@ -675,9 +722,11 @@ def InitRecord():
     records.Index=0
     records.LastIndex=0
     records.StartTime_tuple=time.localtime()
+#    records.StartTime_tuple=data.StartTime_seconds
     records.StartTime_seconds=Tuple2Seconds(records.StartTime_tuple)
     records.EndTime_tuple=records.StartTime_tuple
     records.EndTime_seconds=records.StartTime_seconds
+    records.AlarmIsSet=False
     records.AlarmTime_tuple=-1
     records.AlarmTime_seconds=-1
     records.AlarmTimeWindowStart_tuple=-1
@@ -685,7 +734,6 @@ def InitRecord():
     records.AlarmTimeWindowEnd_tuple=-1
     records.AlarmTimeWindowEnd_seconds=-1
     records.AlarmTimeWindow_minutes=-1
-    records.AlarmIsSet=False
     records.Note=""
     records.Sampling_interval=-1
     records.Sample_smoothing=-1
@@ -694,6 +742,18 @@ def InitRecord():
     records.status=""
     records.statusID=""
 
+    records.Lucid_Dream_Song_Start_tuple = -1
+    records.Use_Lucid_Dream_Song = False
+    records.Lucid_Dream_Song = ""
+    records.Lucid_Dream_Song_Delay = -1
+    records.Lucid_Dream_Song_Volume = -1
+
+    records.WakeUp_Song_Start_tuple = -1
+    records.Use_WakeUp_Song = False
+    records.WakeUp_Song = ""
+    records.WakeUp_Song_Duration = -1
+    records.WakeUp_Song_Volume= -1
+
     for i in range(0, records.MaxArrayDataLen-1): #clear data of old records
         for j in range(0,  6):
             records.arrData[j][i]=0
@@ -724,6 +784,7 @@ def PrintRecordData(ShowArray=True):
     print "StartTime_seconds:",  records.StartTime_seconds
     print "EndTime_tuple:",  records.EndTime_tuple
     print "EndTime_seconds:",  records.EndTime_seconds
+    print "AlarmIsSet:",  records.AlarmIsSet
     print "AlarmTime_tuple:",  records.AlarmTime_tuple
     print "AlarmTime_seconds:",  records.AlarmTime_seconds
     print "AlarmTimeWindowStart_tuple:",  records.AlarmTimeWindowStart_tuple
@@ -731,7 +792,6 @@ def PrintRecordData(ShowArray=True):
     print "AlarmTimeWindowEnd_tuple:",  records.AlarmTimeWindowEnd_tuple
     print "AlarmTimeWindowEnd_seconds",  records.AlarmTimeWindowEnd_seconds
     print "AlarmTimeWindow_minutes:",  records.AlarmTimeWindow_minutes
-    print "AlarmIsSet:",  records.AlarmIsSet
     print "Note:",  records.Note
     print "Sampling_interval:",  records.Sampling_interval
     print "Sample_smoothing:",  records.Sample_smoothing
@@ -739,6 +799,21 @@ def PrintRecordData(ShowArray=True):
     print "Trigger:",  records.Trigger
     print "Status:",  records.statusID,  records.status
 
+    print "Use_Lucid_Dream_Song:",  records.Use_Lucid_Dream_Song
+    print "Lucid_Dream_Song_Start_tuple:",  records.Lucid_Dream_Song_Start_tuple
+    print "Lucid_Dream_Song:",  records.Lucid_Dream_Song
+    print "Lucid_Dream_Song_Delay:",  records.Lucid_Dream_Song_Delay
+    print "Lucid_Dream_Song_Duration:",  records.Lucid_Dream_Song_Duration
+    print "Lucid_Dream_Song_Volume:",  records.Lucid_Dream_Song_Volume
+
+    print "Use_WakeUp_Song:",  records.Use_WakeUp_Song
+    print "WakeUp_Song_Start_tuple:",  records.WakeUp_Song_Start_tuple
+    print "WakeUp_Song:",  records.WakeUp_Song
+    print "WakeUp_Song_Duration:",  records.WakeUp_Song_Duration
+    print "WakeUp_Song_Volume:",  records.WakeUp_Song_Volume
+
+
+
     if(ShowArray==True):
         for i in range(0, records.Index): #print data of  records
             print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i],  records.arrData[6][i]
